powered by
is_mgi_identifier() checks whether the input is of the format "MGI:nnnnnn", where "n" is a digit and the number of digits can vary.
is_mgi_identifier()
"MGI:nnnnnn"
"n"
is_mgi_identifier(x)
A logical vector.
A character vector.