Learn R Programming

mgi.report.reader (version 0.1.3)

open_marker_symbol_in_mgi: Browse MGI markers symbols online

Description

open_marker_symbol_in_mgi() launches the web browser and opens a tab for each MGI symbol on the Mouse Genome Informatics web interface: https://www.informatics.jax.org.

Usage

open_marker_symbol_in_mgi(marker_symbol)

Value

Returns TRUE if successful, or FALSE otherwise. But note that this function is run for its side effect of launching the browser.

Arguments

marker_symbol

A character vector. MGI marker symbols.

Examples

Run this code
# Read about Acta1 (actin alpha 1, skeletal muscle) online.
open_marker_symbol_in_mgi("Acta1")

# `open_marker_symbol_in_mgi()` is vectorized, so you can open multiple pages.
# NB: think twice if you really need to open many tabs at once.
open_marker_symbol_in_mgi(c("Acta1", "Hes1"))

Run the code above in your browser using DataLab