read_symbol_to_id_map() reads MRK_List1.rpt data and returns an efficient
data table to be used for marker symbol remapping to marker identifiers. Note
that old symbols will be remapped to new symbols' ids, if applicable.
This function is memoised.
read_symbol_to_id_map(report_file = NULL, n_max = Inf)A data.table where each row is a mapping,
from marker_symbol to marker_id_now:
marker_symbol (set as key): marker symbol is a unique abbreviation of the marker name.
marker_id_now: genetic marker identifier replacement. If the record pertains a marker_symbol that was withdrawn, then marker_id_now indicates the most recent in-use marker identifier that replaced it.
The path to a MRK_List1.rpt file. Leave this as NULL
and the function will automatically download the report from
https://www.informatics.jax.org/downloads/reports/MRK_List1.rpt.
Maximum number of lines to read.